@@ -7,6 +7,7 @@ from typing import Union, List, Optional, Dict
 import slack.errors as e
 from slack.web.base_client import BaseClient, SlackResponse
 from slack.web.classes.views import View
+from slack.web.internal_utils import _parse_web_class_objects, _update_call_participants
 
 
 class WebClient(BaseClient):
@@ -533,10 +534,12 @@ class WebClient(BaseClient):
                 e.g. 'https://example.com/calls/1234567890'
         """
         kwargs.update({"external_unique_id": external_unique_id, "join_url": join_url})
-        self._update_call_participants(kwargs, kwargs.get("users", None))
+        _update_call_participants(kwargs, kwargs.get("users", None))
         return self.api_call("calls.add", http_verb="POST", params=kwargs)
 
-    def calls_end(self, *, id: str, **kwargs) -> Union[Future, SlackResponse]:
+    def calls_end(
+        self, *, id: str, **kwargs  # skipcq: PYL-W0622
+    ) -> Union[Future, SlackResponse]:
         """Ends a Call.
 
         Args:
@@ -545,7 +548,9 @@ class WebClient(BaseClient):
         kwargs.update({"id": id})
         return self.api_call("calls.end", http_verb="POST", params=kwargs)
 
-    def calls_info(self, *, id: str, **kwargs) -> Union[Future, SlackResponse]:
+    def calls_info(
+        self, *, id: str, **kwargs  # skipcq: PYL-W0622
+    ) -> Union[Future, SlackResponse]:
         """Returns information about a Call.
 
         Args:
@@ -555,7 +560,11 @@ class WebClient(BaseClient):
         return self.api_call("calls.info", http_verb="POST", params=kwargs)
 
     def calls_participants_add(
-        self, *, id: str, users: Union[str, List[Dict[str, str]]], **kwargs
+        self,
+        *,
+        id: str,  # skipcq: PYL-W0622
+        users: Union[str, List[Dict[str, str]]],
+        **kwargs
     ) -> Union[Future, SlackResponse]:
         """Registers new participants added to a Call.
 
@@ -564,11 +573,15 @@ class WebClient(BaseClient):
             users: (list): The list of users to add as participants in the Call.
         """
         kwargs.update({"id": id})
-        self._update_call_participants(kwargs, users)
+        _update_call_participants(kwargs, users)
         return self.api_call("calls.participants.add", http_verb="POST", params=kwargs)
 
     def calls_participants_remove(
-        self, *, id: str, users: Union[str, List[Dict[str, str]]], **kwargs
+        self,
+        *,
+        id: str,  # skipcq: PYL-W0622
+        users: Union[str, List[Dict[str, str]]],
+        **kwargs
     ) -> Union[Future, SlackResponse]:
         """Registers participants removed from a Call.
 
@@ -577,12 +590,14 @@ class WebClient(BaseClient):
             users: (list): The list of users to remove as participants in the Call.
         """
         kwargs.update({"id": id})
-        self._update_call_participants(kwargs, users)
+        _update_call_participants(kwargs, users)
         return self.api_call(
             "calls.participants.remove", http_verb="POST", params=kwargs
         )
 
-    def calls_update(self, *, id: str, **kwargs) -> Union[Future, SlackResponse]:
+    def calls_update(
+        self, *, id: str, **kwargs  # skipcq: PYL-W0622
+    ) -> Union[Future, SlackResponse]:
         """Updates information about a Call.
 
         Args:
@@ -814,7 +829,7 @@ class WebClient(BaseClient):
                 e.g. [{"type": "section", "text": {"type": "plain_text", "text": "Hello world"}}]
         """
         kwargs.update({"channel": channel, "user": user})
-        self._parse_web_class_objects(kwargs)
+        _parse_web_class_objects(kwargs)
         return self.api_call("chat.postEphemeral", json=kwargs)
 
     def chat_postMessage(
@@ -831,7 +846,7 @@ class WebClient(BaseClient):
                 e.g. [{"type": "section", "text": {"type": "plain_text", "text": "Hello world"}}]
         """
         kwargs.update({"channel": channel})
-        self._parse_web_class_objects(kwargs)
+        _parse_web_class_objects(kwargs)
         return self.api_call("chat.postMessage", json=kwargs)
 
     def chat_scheduleMessage(
@@ -845,7 +860,7 @@ class WebClient(BaseClient):
             text (str): The message you'd like to send. e.g. 'Hello world'
         """
         kwargs.update({"channel": channel, "post_at": post_at, "text": text})
-        self._parse_web_class_objects(kwargs)
+        _parse_web_class_objects(kwargs)
         return self.api_call("chat.scheduleMessage", json=kwargs)
 
     def chat_unfurl(
@@ -877,7 +892,7 @@ class WebClient(BaseClient):
                 e.g. [{"type": "section", "text": {"type": "plain_text", "text": "Hello world"}}]
         """
         kwargs.update({"channel": channel, "ts": ts})
-        self._parse_web_class_objects(kwargs)
+        _parse_web_class_objects(kwargs)
         return self.api_call("chat.update", json=kwargs)
 
     def chat_scheduledMessages_list(self, **kwargs) -> Union[Future, SlackResponse]:
@@ -1152,7 +1167,7 @@ class WebClient(BaseClient):
         return self.api_call("emoji.list", http_verb="GET", params=kwargs)
 
     def files_comments_delete(
-        self, *, file: str, id: str, **kwargs
+        self, *, file: str, id: str, **kwargs  # skipcq: PYL-W0622
     ) -> Union[Future, SlackResponse]:
         """Deletes an existing comment on a file.
 
@@ -2013,12 +2028,7 @@ class WebClient(BaseClient):
         self, *, trigger_id: str, view: Union[dict, View], **kwargs
     ) -> Union[Future, SlackResponse]:
         """Open a view for a user.
-
-        Open a modal with a user by exchanging a trigger_id received
-        from another interaction.
-​
-        See the modals (https://api.slack.com/block-kit/surfaces/modals)
-        documentation to learn how to obtain triggers from interactive components.
+        See https://api.slack.com/block-kit/surfaces/modals for details.
 
         Args:
             trigger_id (str): Exchange a trigger to post to the user.
